==> lam_6.3.2.orig.tar.gz: lam-6.3.2/share/mpi/graphget.c <==
/*
 *
 * Copyright 1998-1999, University of Notre Dame.
 * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
 *          and Andrew Lumsdaine
 *
 * This file is part of the Notre Dame LAM implementation of MPI.
 *
 * You should have received a copy of the License Agreement for the
 * Notre Dame LAM implementation of MPI along with the software; see
 * the file LICENSE.  If not, contact Office of Research, University
 * of Notre Dame, Notre Dame, IN 46556.
 *
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 *
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.  
 *
 * Additional copyrights may follow.
 *
 *	Ohio Trollius
 *	Copyright 1996 The Ohio State University
 *	RBD
 *
 *	$Id: graphget.c,v 6.2 1999/05/25 22:07:56 kmeyer1 Exp $
 *
 *	Function:	- get nodes/edges in graph topology
 *	Accepts:	- communicator
 *			- size of nodes array
 *			- size of edges array
 *			- nodes array
 *			- edges array
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>

int
MPI_Graph_get(comm, maxnodes, maxedges, nodes, edges)

MPI_Comm		comm;
int			maxnodes;
int			maxedges;
int			*nodes;
int			*edges;

{
	int		i;
	int		*p;

	lam_initerr();
	lam_setfunc(BLKMPIGRAPHGET);
/*
 * Check the arguments.
 */
	if (comm == MPI_COMM_NULL) {
		return(lam_errfunc(MPI_COMM_WORLD,
			BLKMPIGRAPHGET, lam_mkerr(MPI_ERR_COMM, 0)));
	}

	if (LAM_IS_INTER(comm)) {
		return(lam_errfunc(comm,
			BLKMPIGRAPHGET, lam_mkerr(MPI_ERR_COMM, 0)));
	}

	if (!LAM_IS_GRAPH(comm)) {
		return(lam_errfunc(comm, BLKMPIGRAPHGET,
				lam_mkerr(MPI_ERR_TOPOLOGY, 0)));
	}

	if ((maxnodes < 0) || (maxedges < 0) || (nodes == 0) || (edges == 0)) {
		return(lam_errfunc(comm,
			BLKMPIGRAPHGET, lam_mkerr(MPI_ERR_ARG, 0)));
	}
/*
 * Fill the nodes and edges arrays.
 */
	p = comm->c_topo_index;
	for (i = 0; (i < comm->c_topo_nprocs) && (i < maxnodes); ++i, ++p) {
		*nodes++ = *p;
	}

	p = comm->c_topo_edges;
	for (i = 0; (i < comm->c_topo_nedges) && (i < maxedges); ++i, ++p) {
		*edges++ = *p;
	}

	lam_resetfunc(BLKMPIGRAPHGET);
	return(MPI_SUCCESS);
}

==> lam-6.5.1.tar.gz: lam-6.5.1/share/mpi/graphget.c <==
/*
 * Copyright 1998-2001, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
 *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
 * 
 * This file is part of the Notre Dame LAM implementation of MPI.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame LAM implementation of MPI along with the software; see the file
 * LICENSE.  If not, contact Office of Research, University of Notre
 * Dame, Notre Dame, IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *	Ohio Trollius
 *	Copyright 1996 The Ohio State University
 *	RBD
 *
 *	$Id: graphget.c,v 6.3 1999/12/31 21:27:27 jsquyres Exp $
 *
 *	Function:	- get nodes/edges in graph topology
 *	Accepts:	- communicator
 *			- size of nodes array
 *			- size of edges array
 *			- nodes array
 *			- edges array
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>

/*@

MPI_Graph_get - Retrieves graph topology information associated with a 
                communicator

Input Parameters:
+ comm - communicator with graph structure (handle) 
. maxnodes - length of vector 'index' in the calling program  (integer) 
- maxedges - length of vector 'edges' in the calling program  (integer) 

Output Parameter:
+ nodes - array of integers containing the graph structure (for details see the definition of 'MPI_GRAPH_CREATE') 
- edges - array of integers containing the graph structure 

.N fortran

.N Errors
.N MPI_SUCCESS
.N MPI_ERR_TOPOLOGY
.N MPI_ERR_COMM
.N MPI_ERR_ARG

.N ACK
@*/
int MPI_Graph_get(MPI_Comm comm, int maxnodes, int maxedges, 
		  int *nodes, int *edges)
{
	int		i;
	int		*p;

	lam_initerr();
	lam_setfunc(BLKMPIGRAPHGET);
/*
 * Check the arguments.
 */
	if (comm == MPI_COMM_NULL) {
		return(lam_errfunc(MPI_COMM_WORLD,
			BLKMPIGRAPHGET, lam_mkerr(MPI_ERR_COMM, 0)));
	}

	if (LAM_IS_INTER(comm)) {
		return(lam_errfunc(comm,
			BLKMPIGRAPHGET, lam_mkerr(MPI_ERR_COMM, 0)));
	}

	if (!LAM_IS_GRAPH(comm)) {
		return(lam_errfunc(comm, BLKMPIGRAPHGET,
				lam_mkerr(MPI_ERR_TOPOLOGY, 0)));
	}

	if ((maxnodes < 0) || (maxedges < 0) || (nodes == 0) || (edges == 0)) {
		return(lam_errfunc(comm,
			BLKMPIGRAPHGET, lam_mkerr(MPI_ERR_ARG, 0)));
	}
/*
 * Fill the nodes and edges arrays.
 */
	p = comm->c_topo_index;
	for (i = 0; (i < comm->c_topo_nprocs) && (i < maxnodes); ++i, ++p) {
		*nodes++ = *p;
	}

	p = comm->c_topo_edges;
	for (i = 0; (i < comm->c_topo_nedges) && (i < maxedges); ++i, ++p) {
		*edges++ = *p;
	}

	lam_resetfunc(BLKMPIGRAPHGET);
	return(MPI_SUCCESS);
}
